@@ -71,7 +71,23 @@ extern void e_marshal_BOOLEAN__VOID (GClosure     *closure,
                                      gpointer      marshal_data);
 #define e_marshal_BOOLEAN__NONE	e_marshal_BOOLEAN__VOID
 
-/* BOOLEAN:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:9) */
+/* BOOLEAN:OBJECT (e-marshal.list:9) */
+extern void e_marshal_BOOLEAN__OBJECT (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data);
+
+/* BOOLEAN:OBJECT,OBJECT (e-marshal.list:10) */
+extern void e_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data);
+
+/* BOOLEAN:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:11) */
 extern void e_marshal_BOOLEAN__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -79,7 +95,7 @@ extern void e_marshal_BOOLEAN__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* BOOLEAN:POINTER (e-marshal.list:10) */
+/* BOOLEAN:POINTER (e-marshal.list:12) */
 extern void e_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -87,7 +103,7 @@ extern void e_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* BOOLEAN:POINTER,BOOLEAN,POINTER (e-marshal.list:11) */
+/* BOOLEAN:POINTER,BOOLEAN,POINTER (e-marshal.list:13) */
 extern void e_marshal_BOOLEAN__POINTER_BOOLEAN_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -95,7 +111,7 @@ extern void e_marshal_BOOLEAN__POINTER_BOOLEAN_POINTER (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* BOOLEAN:POINTER,POINTER (e-marshal.list:12) */
+/* BOOLEAN:POINTER,POINTER (e-marshal.list:14) */
 extern void e_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -103,7 +119,7 @@ extern void e_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* BOOLEAN:POINTER,POINTER,POINTER,POINTER (e-marshal.list:13) */
+/* BOOLEAN:POINTER,POINTER,POINTER,POINTER (e-marshal.list:15) */
 extern void e_marshal_BOOLEAN__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -111,7 +127,7 @@ extern void e_marshal_BOOLEAN__POINTER_POINTER_POINTER_POINTER (GClosure     *cl
                                                                 gpointer      invocation_hint,
                                                                 gpointer      marshal_data);
 
-/* BOOLEAN:STRING (e-marshal.list:14) */
+/* BOOLEAN:STRING (e-marshal.list:16) */
 extern void e_marshal_BOOLEAN__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -119,7 +135,7 @@ extern void e_marshal_BOOLEAN__STRING (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* BOOLEAN:STRING,INT (e-marshal.list:15) */
+/* BOOLEAN:STRING,INT (e-marshal.list:17) */
 extern void e_marshal_BOOLEAN__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -127,7 +143,7 @@ extern void e_marshal_BOOLEAN__STRING_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* DOUBLE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:16) */
+/* DOUBLE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:18) */
 extern void e_marshal_DOUBLE__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -135,7 +151,7 @@ extern void e_marshal_DOUBLE__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closur
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);
 
-/* INT:BOXED (e-marshal.list:17) */
+/* INT:BOXED (e-marshal.list:19) */
 extern void e_marshal_INT__BOXED (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
@@ -143,7 +159,7 @@ extern void e_marshal_INT__BOXED (GClosure     *closure,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);
 
-/* INT:INT (e-marshal.list:18) */
+/* INT:INT (e-marshal.list:20) */
 extern void e_marshal_INT__INT (GClosure     *closure,
                                 GValue       *return_value,
                                 guint         n_param_values,
@@ -151,7 +167,7 @@ extern void e_marshal_INT__INT (GClosure     *closure,
                                 gpointer      invocation_hint,
                                 gpointer      marshal_data);
 
-/* INT:INT,INT,BOXED (e-marshal.list:19) */
+/* INT:INT,INT,BOXED (e-marshal.list:21) */
 extern void e_marshal_INT__INT_INT_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -159,7 +175,7 @@ extern void e_marshal_INT__INT_INT_BOXED (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* INT:INT,POINTER,INT,BOXED (e-marshal.list:20) */
+/* INT:INT,POINTER,INT,BOXED (e-marshal.list:22) */
 extern void e_marshal_INT__INT_POINTER_INT_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -167,7 +183,7 @@ extern void e_marshal_INT__INT_POINTER_INT_BOXED (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* INT:OBJECT,BOXED (e-marshal.list:21) */
+/* INT:OBJECT,BOXED (e-marshal.list:23) */
 extern void e_marshal_INT__OBJECT_BOXED (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -175,7 +191,7 @@ extern void e_marshal_INT__OBJECT_BOXED (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* INT:POINTER (e-marshal.list:22) */
+/* INT:POINTER (e-marshal.list:24) */
 extern void e_marshal_INT__POINTER (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
@@ -183,7 +199,7 @@ extern void e_marshal_INT__POINTER (GClosure     *closure,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
 
-/* NONE:BOXED,INT (e-marshal.list:23) */
+/* NONE:BOXED,INT (e-marshal.list:25) */
 extern void e_marshal_VOID__BOXED_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -192,7 +208,7 @@ extern void e_marshal_VOID__BOXED_INT (GClosure     *closure,
                                        gpointer      marshal_data);
 #define e_marshal_NONE__BOXED_INT	e_marshal_VOID__BOXED_INT
 
-/* NONE:ENUM,OBJECT,OBJECT (e-marshal.list:24) */
+/* NONE:ENUM,OBJECT,OBJECT (e-marshal.list:26) */
 extern void e_marshal_VOID__ENUM_OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -201,7 +217,7 @@ extern void e_marshal_VOID__ENUM_OBJECT_OBJECT (GClosure     *closure,
                                                 gpointer      marshal_data);
 #define e_marshal_NONE__ENUM_OBJECT_OBJECT	e_marshal_VOID__ENUM_OBJECT_OBJECT
 
-/* NONE:INT,INT (e-marshal.list:25) */
+/* NONE:INT,INT (e-marshal.list:27) */
 extern void e_marshal_VOID__INT_INT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -210,7 +226,7 @@ extern void e_marshal_VOID__INT_INT (GClosure     *closure,
                                      gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT	e_marshal_VOID__INT_INT
 
-/* NONE:INT,INT,BOXED (e-marshal.list:26) */
+/* NONE:INT,INT,BOXED (e-marshal.list:28) */
 extern void e_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -219,7 +235,7 @@ extern void e_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_BOXED	e_marshal_VOID__INT_INT_BOXED
 
-/* NONE:INT,INT,OBJECT (e-marshal.list:27) */
+/* NONE:INT,INT,OBJECT (e-marshal.list:29) */
 extern void e_marshal_VOID__INT_INT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -228,7 +244,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT	e_marshal_VOID__INT_INT_OBJECT
 
-/* NONE:INT,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:28) */
+/* NONE:INT,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:30) */
 extern void e_marshal_VOID__INT_INT_OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -237,7 +253,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT_BOXED_UINT_UINT (GClosure     *closur
                                                             gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT_BOXED_UINT_UINT	e_marshal_VOID__INT_INT_OBJECT_BOXED_UINT_UINT
 
-/* NONE:INT,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:29) */
+/* NONE:INT,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:31) */
 extern void e_marshal_VOID__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                                     GValue       *return_value,
                                                                     guint         n_param_values,
@@ -246,7 +262,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClosure
                                                                     gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT	e_marshal_VOID__INT_INT_OBJECT_INT_INT_BOXED_UINT_UINT
 
-/* NONE:INT,INT,OBJECT,UINT (e-marshal.list:30) */
+/* NONE:INT,INT,OBJECT,UINT (e-marshal.list:32) */
 extern void e_marshal_VOID__INT_INT_OBJECT_UINT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -255,7 +271,7 @@ extern void e_marshal_VOID__INT_INT_OBJECT_UINT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define e_marshal_NONE__INT_INT_OBJECT_UINT	e_marshal_VOID__INT_INT_OBJECT_UINT
 
-/* NONE:INT,OBJECT (e-marshal.list:31) */
+/* NONE:INT,OBJECT (e-marshal.list:33) */
 extern void e_marshal_VOID__INT_OBJECT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -264,7 +280,7 @@ extern void e_marshal_VOID__INT_OBJECT (GClosure     *closure,
                                         gpointer      marshal_data);
 #define e_marshal_NONE__INT_OBJECT	e_marshal_VOID__INT_OBJECT
 
-/* NONE:INT,POINTER (e-marshal.list:32) */
+/* NONE:INT,POINTER (e-marshal.list:34) */
 extern void e_marshal_VOID__INT_POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -273,7 +289,7 @@ extern void e_marshal_VOID__INT_POINTER (GClosure     *closure,
                                          gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER	e_marshal_VOID__INT_POINTER
 
-/* NONE:INT,POINTER,INT,BOXED (e-marshal.list:33) */
+/* NONE:INT,POINTER,INT,BOXED (e-marshal.list:35) */
 extern void e_marshal_VOID__INT_POINTER_INT_BOXED (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -282,7 +298,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_BOXED (GClosure     *closure,
                                                    gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_BOXED	e_marshal_VOID__INT_POINTER_INT_BOXED
 
-/* NONE:INT,POINTER,INT,OBJECT (e-marshal.list:34) */
+/* NONE:INT,POINTER,INT,OBJECT (e-marshal.list:36) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -291,7 +307,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT (GClosure     *closure,
                                                     gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT	e_marshal_VOID__INT_POINTER_INT_OBJECT
 
-/* NONE:INT,POINTER,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:35) */
+/* NONE:INT,POINTER,INT,OBJECT,BOXED,UINT,UINT (e-marshal.list:37) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                                                     GValue       *return_value,
                                                                     guint         n_param_values,
@@ -300,7 +316,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT (GClosure
                                                                     gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT	e_marshal_VOID__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT
 
-/* NONE:INT,POINTER,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:36) */
+/* NONE:INT,POINTER,INT,OBJECT,INT,INT,BOXED,UINT,UINT (e-marshal.list:38) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                                             GValue       *return_value,
                                                                             guint         n_param_values,
@@ -309,7 +325,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT (GClo
                                                                             gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT	e_marshal_VOID__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT
 
-/* NONE:INT,POINTER,INT,OBJECT,UINT (e-marshal.list:37) */
+/* NONE:INT,POINTER,INT,OBJECT,UINT (e-marshal.list:39) */
 extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_UINT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -318,7 +334,7 @@ extern void e_marshal_VOID__INT_POINTER_INT_OBJECT_UINT (GClosure     *closure,
                                                          gpointer      marshal_data);
 #define e_marshal_NONE__INT_POINTER_INT_OBJECT_UINT	e_marshal_VOID__INT_POINTER_INT_OBJECT_UINT
 
-/* NONE:LONG,LONG (e-marshal.list:38) */
+/* NONE:LONG,LONG (e-marshal.list:40) */
 extern void e_marshal_VOID__LONG_LONG (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -327,7 +343,7 @@ extern void e_marshal_VOID__LONG_LONG (GClosure     *closure,
                                        gpointer      marshal_data);
 #define e_marshal_NONE__LONG_LONG	e_marshal_VOID__LONG_LONG
 
-/* NONE:OBJECT,BOOLEAN (e-marshal.list:39) */
+/* NONE:OBJECT,BOOLEAN (e-marshal.list:41) */
 extern void e_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -336,7 +352,7 @@ extern void e_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_BOOLEAN	e_marshal_VOID__OBJECT_BOOLEAN
 
-/* NONE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:40) */
+/* NONE:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:42) */
 extern void e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -345,7 +361,7 @@ extern void e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                           gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_DOUBLE_DOUBLE_BOOLEAN	e_marshal_VOID__OBJECT_DOUBLE_DOUBLE_BOOLEAN
 
-/* NONE:OBJECT,OBJECT (e-marshal.list:41) */
+/* NONE:OBJECT,OBJECT (e-marshal.list:43) */
 extern void e_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -354,7 +370,7 @@ extern void e_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_OBJECT	e_marshal_VOID__OBJECT_OBJECT
 
-/* NONE:OBJECT,STRING (e-marshal.list:42) */
+/* NONE:OBJECT,STRING (e-marshal.list:44) */
 extern void e_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -363,34 +379,7 @@ extern void e_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_STRING	e_marshal_VOID__OBJECT_STRING
 
-/* NONE:OBJECT,STRING,INT (e-marshal.list:43) */
-extern void e_marshal_VOID__OBJECT_STRING_INT (GClosure     *closure,
-                                               GValue       *return_value,
-                                               guint         n_param_values,
-                                               const GValue *param_values,
-                                               gpointer      invocation_hint,
-                                               gpointer      marshal_data);
-#define e_marshal_NONE__OBJECT_STRING_INT	e_marshal_VOID__OBJECT_STRING_INT
-
-/* NONE:OBJECT,STRING,INT,STRING,STRING,STRING (e-marshal.list:44) */
-extern void e_marshal_VOID__OBJECT_STRING_INT_STRING_STRING_STRING (GClosure     *closure,
-                                                                    GValue       *return_value,
-                                                                    guint         n_param_values,
-                                                                    const GValue *param_values,
-                                                                    gpointer      invocation_hint,
-                                                                    gpointer      marshal_data);
-#define e_marshal_NONE__OBJECT_STRING_INT_STRING_STRING_STRING	e_marshal_VOID__OBJECT_STRING_INT_STRING_STRING_STRING
-
-/* NONE:OBJECT,STRING,STRING (e-marshal.list:45) */
-extern void e_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
-                                                  GValue       *return_value,
-                                                  guint         n_param_values,
-                                                  const GValue *param_values,
-                                                  gpointer      invocation_hint,
-                                                  gpointer      marshal_data);
-#define e_marshal_NONE__OBJECT_STRING_STRING	e_marshal_VOID__OBJECT_STRING_STRING
-
-/* NONE:OBJECT,STRING,UINT (e-marshal.list:46) */
+/* NONE:OBJECT,STRING,UINT (e-marshal.list:45) */
 extern void e_marshal_VOID__OBJECT_STRING_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -399,7 +388,7 @@ extern void e_marshal_VOID__OBJECT_STRING_UINT (GClosure     *closure,
                                                 gpointer      marshal_data);
 #define e_marshal_NONE__OBJECT_STRING_UINT	e_marshal_VOID__OBJECT_STRING_UINT
 
-/* NONE:POINTER,INT (e-marshal.list:47) */
+/* NONE:POINTER,INT (e-marshal.list:46) */
 extern void e_marshal_VOID__POINTER_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -408,7 +397,7 @@ extern void e_marshal_VOID__POINTER_INT (GClosure     *closure,
                                          gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT	e_marshal_VOID__POINTER_INT
 
-/* NONE:POINTER,INT,INT,INT,INT (e-marshal.list:48) */
+/* NONE:POINTER,INT,INT,INT,INT (e-marshal.list:47) */
 extern void e_marshal_VOID__POINTER_INT_INT_INT_INT (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -417,7 +406,7 @@ extern void e_marshal_VOID__POINTER_INT_INT_INT_INT (GClosure     *closure,
                                                      gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT_INT_INT_INT	e_marshal_VOID__POINTER_INT_INT_INT_INT
 
-/* NONE:POINTER,INT,OBJECT (e-marshal.list:49) */
+/* NONE:POINTER,INT,OBJECT (e-marshal.list:48) */
 extern void e_marshal_VOID__POINTER_INT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -426,7 +415,7 @@ extern void e_marshal_VOID__POINTER_INT_OBJECT (GClosure     *closure,
                                                 gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT_OBJECT	e_marshal_VOID__POINTER_INT_OBJECT
 
-/* NONE:POINTER,OBJECT (e-marshal.list:50) */
+/* NONE:POINTER,OBJECT (e-marshal.list:49) */
 extern void e_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -435,7 +424,7 @@ extern void e_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_OBJECT	e_marshal_VOID__POINTER_OBJECT
 
-/* NONE:POINTER,POINTER (e-marshal.list:51) */
+/* NONE:POINTER,POINTER (e-marshal.list:50) */
 extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -444,7 +433,7 @@ extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER	e_marshal_VOID__POINTER_POINTER
 
-/* NONE:POINTER,POINTER,INT (e-marshal.list:52) */
+/* NONE:POINTER,POINTER,INT (e-marshal.list:51) */
 extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -453,7 +442,7 @@ extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER_INT	e_marshal_VOID__POINTER_POINTER_INT
 
-/* NONE:STRING,DOUBLE (e-marshal.list:53) */
+/* NONE:STRING,DOUBLE (e-marshal.list:52) */
 extern void e_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -462,7 +451,7 @@ extern void e_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                            gpointer      marshal_data);
 #define e_marshal_NONE__STRING_DOUBLE	e_marshal_VOID__STRING_DOUBLE
 
-/* NONE:STRING,INT (e-marshal.list:54) */
+/* NONE:STRING,INT (e-marshal.list:53) */
 extern void e_marshal_VOID__STRING_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -471,7 +460,7 @@ extern void e_marshal_VOID__STRING_INT (GClosure     *closure,
                                         gpointer      marshal_data);
 #define e_marshal_NONE__STRING_INT	e_marshal_VOID__STRING_INT
 
-/* NONE:STRING,INT,INT (e-marshal.list:55) */
+/* NONE:STRING,INT,INT (e-marshal.list:54) */
 extern void e_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -480,6 +469,15 @@ extern void e_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                             gpointer      marshal_data);
 #define e_marshal_NONE__STRING_INT_INT	e_marshal_VOID__STRING_INT_INT
 
+/* NONE:STRING,OBJECT (e-marshal.list:55) */
+extern void e_marshal_VOID__STRING_OBJECT (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
+#define e_marshal_NONE__STRING_OBJECT	e_marshal_VOID__STRING_OBJECT
+
 /* NONE:STRING,POINTER,POINTER (e-marshal.list:56) */
 extern void e_marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
